Welcome to Quantify's documentation!
======================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:

   installation
   usage
   dataset_spec
   contributing
   authors
   changelog


Tutorials
==============

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/Tutorial 1. Controlling a basic experiment using MeasurementControl.rst
   tutorials/Tutorial 2. Advanced capabilities of the MeasurementControl.rst
   tutorials/Tutorial 3. Adaptive Measurements.rst


API Reference
===================

Contents:

.. toctree::
   :maxdepth: 2
   :caption: API reference

   api_reference


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
